summaryrefslogtreecommitdiff
path: root/sc/source/core/inc/bcaslot.hxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
commitcd42389ad67b403a07a0dda8e2a6e213def49251 (patch)
tree51e19c743788a549502b7c801c64e11142103310 /sc/source/core/inc/bcaslot.hxx
parent3d6a5a98cda10e18dacd96028f2bf0ec0b478988 (diff)
removetooltypes01: #i112600# remove tooltypes from sc
Diffstat (limited to 'sc/source/core/inc/bcaslot.hxx')
-rw-r--r--sc/source/core/inc/bcaslot.hxx30
1 files changed, 15 insertions, 15 deletions
diff --git a/sc/source/core/inc/bcaslot.hxx b/sc/source/core/inc/bcaslot.hxx
index 13384b033628..a912a8c6e550 100644
--- a/sc/source/core/inc/bcaslot.hxx
+++ b/sc/source/core/inc/bcaslot.hxx
@@ -47,13 +47,13 @@ private:
ScBroadcastArea* pUpdateChainNext;
SvtBroadcaster aBroadcaster;
ScRange aRange;
- ULONG nRefCount;
- BOOL bInUpdateChain;
+ sal_uLong nRefCount;
+ sal_Bool bInUpdateChain;
public:
ScBroadcastArea( const ScRange& rRange )
: pUpdateChainNext( NULL ), aRange( rRange ),
- nRefCount( 0 ), bInUpdateChain( FALSE ) {}
+ nRefCount( 0 ), bInUpdateChain( sal_False ) {}
inline SvtBroadcaster& GetBroadcaster() { return aBroadcaster; }
inline const SvtBroadcaster& GetBroadcaster() const { return aBroadcaster; }
inline void UpdateRange( const ScRange& rNewRange )
@@ -62,12 +62,12 @@ public:
inline const ScAddress& GetStart() const { return aRange.aStart; }
inline const ScAddress& GetEnd() const { return aRange.aEnd; }
inline void IncRef() { ++nRefCount; }
- inline ULONG DecRef() { return nRefCount ? --nRefCount : 0; }
- inline ULONG GetRef() { return nRefCount; }
+ inline sal_uLong DecRef() { return nRefCount ? --nRefCount : 0; }
+ inline sal_uLong GetRef() { return nRefCount; }
inline ScBroadcastArea* GetUpdateChainNext() const { return pUpdateChainNext; }
inline void SetUpdateChainNext( ScBroadcastArea* p ) { pUpdateChainNext = p; }
- inline BOOL IsInUpdateChain() const { return bInUpdateChain; }
- inline void SetInUpdateChain( BOOL b ) { bInUpdateChain = b; }
+ inline sal_Bool IsInUpdateChain() const { return bInUpdateChain; }
+ inline void SetInUpdateChain( sal_Bool b ) { bInUpdateChain = b; }
/** Equalness of this or range. */
inline bool operator==( const ScBroadcastArea & rArea ) const;
@@ -139,7 +139,7 @@ private:
whether there would be an overflow when adding an area, setting the
proper state if so.
- @return TRUE if a HardRecalcState is effective and area is not to be
+ @return sal_True if a HardRecalcState is effective and area is not to be
added.
*/
bool CheckHardRecalcStateCondition() const;
@@ -165,7 +165,7 @@ public:
as InsertListeningArea(), so use that instead.
@return
- TRUE if rpArea passed was NULL and ScBroadcastArea is newly
+ sal_True if rpArea passed was NULL and ScBroadcastArea is newly
created.
*/
bool StartListeningArea( const ScRange& rRange,
@@ -181,9 +181,9 @@ public:
void EndListeningArea( const ScRange& rRange,
SvtListener* pListener,
ScBroadcastArea*& rpArea );
- BOOL AreaBroadcast( const ScHint& rHint ) const;
- /// @return TRUE if at least one broadcast occurred.
- BOOL AreaBroadcastInRange( const ScRange& rRange,
+ sal_Bool AreaBroadcast( const ScHint& rHint ) const;
+ /// @return sal_True if at least one broadcast occurred.
+ sal_Bool AreaBroadcastInRange( const ScRange& rRange,
const ScHint& rHint ) const;
void DelBroadcastAreasInRange( const ScRange& rRange );
void UpdateRemove( UpdateRefMode eUpdateRefMode,
@@ -245,7 +245,7 @@ private:
ScDocument *pDoc;
ScBroadcastArea *pUpdateChain;
ScBroadcastArea *pEOUpdateChain;
- ULONG nInBulkBroadcast;
+ sal_uLong nInBulkBroadcast;
inline SCSIZE ComputeSlotOffset( const ScAddress& rAddress ) const;
void ComputeAreaPoints( const ScRange& rRange,
@@ -259,9 +259,9 @@ public:
SvtListener* pListener );
void EndListeningArea( const ScRange& rRange,
SvtListener* pListener );
- BOOL AreaBroadcast( const ScHint& rHint ) const;
+ sal_Bool AreaBroadcast( const ScHint& rHint ) const;
// return: at least one broadcast occurred
- BOOL AreaBroadcastInRange( const ScRange& rRange, const ScHint& rHint ) const;
+ sal_Bool AreaBroadcastInRange( const ScRange& rRange, const ScHint& rHint ) const;
void DelBroadcastAreasInRange( const ScRange& rRange );
void UpdateBroadcastAreas( UpdateRefMode eUpdateRefMode,
const ScRange& rRange,